==> zio-aws-codecommit_2.13-5.17.182.1-sources.jar: zio/aws/codecommit/model/DisassociateApprovalRuleTemplateFromRepositoryRequest.scala <==
package zio.aws.codecommit.model
import zio.aws.codecommit.model.primitives.{
  RepositoryName,
  ApprovalRuleTemplateName
}
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DisassociateApprovalRuleTemplateFromRepositoryRequest(
    approvalRuleTemplateName: ApprovalRuleTemplateName,
    repositoryName: RepositoryName
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codecommit.model.DisassociateApprovalRuleTemplateFromRepositoryRequest = {
    import DisassociateApprovalRuleTemplateFromRepositoryRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codecommit.model.DisassociateApprovalRuleTemplateFromRepositoryRequest
      .builder()
      .approvalRuleTemplateName(
        ApprovalRuleTemplateName.unwrap(
          approvalRuleTemplateName
        ): java.lang.String
      )
      .repositoryName(RepositoryName.unwrap(repositoryName): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.codecommit.model.DisassociateApprovalRuleTemplateFromRepositoryRequest.ReadOnly =
    zio.aws.codecommit.model.DisassociateApprovalRuleTemplateFromRepositoryRequest
      .wrap(buildAwsValue())
}
object DisassociateApprovalRuleTemplateFromRepositoryRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codecommit.model.DisassociateApprovalRuleTemplateFromRepositoryRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.codecommit.model.DisassociateApprovalRuleTemplateFromRepositoryRequest =
      zio.aws.codecommit.model
        .DisassociateApprovalRuleTemplateFromRepositoryRequest(
          approvalRuleTemplateName,
          repositoryName
        )
    def approvalRuleTemplateName: ApprovalRuleTemplateName
    def repositoryName: RepositoryName
    def getApprovalRuleTemplateName
        : ZIO[Any, Nothing, ApprovalRuleTemplateName] =
      ZIO.succeed(approvalRuleTemplateName)
    def getRepositoryName: ZIO[Any, Nothing, RepositoryName] =
      ZIO.succeed(repositoryName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codecommit.model.DisassociateApprovalRuleTemplateFromRepositoryRequest
  ) extends zio.aws.codecommit.model.DisassociateApprovalRuleTemplateFromRepositoryRequest.ReadOnly {
    override val approvalRuleTemplateName: ApprovalRuleTemplateName =
      zio.aws.codecommit.model.primitives
        .ApprovalRuleTemplateName(impl.approvalRuleTemplateName())
    override val repositoryName: RepositoryName =
      zio.aws.codecommit.model.primitives.RepositoryName(impl.repositoryName())
  }
  def wrap(
      impl: software.amazon.awssdk.services.codecommit.model.DisassociateApprovalRuleTemplateFromRepositoryRequest
  ): zio.aws.codecommit.model.DisassociateApprovalRuleTemplateFromRepositoryRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-codecommit_3-7.28.29.4-sources.jar: zio/aws/codecommit/model/DisassociateApprovalRuleTemplateFromRepositoryRequest.scala <==
package zio.aws.codecommit.model
import zio.aws.codecommit.model.primitives.{
  RepositoryName,
  ApprovalRuleTemplateName
}
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DisassociateApprovalRuleTemplateFromRepositoryRequest(
    approvalRuleTemplateName: ApprovalRuleTemplateName,
    repositoryName: RepositoryName
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codecommit.model.DisassociateApprovalRuleTemplateFromRepositoryRequest = {
    import DisassociateApprovalRuleTemplateFromRepositoryRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codecommit.model.DisassociateApprovalRuleTemplateFromRepositoryRequest
      .builder()
      .approvalRuleTemplateName(
        ApprovalRuleTemplateName.unwrap(
          approvalRuleTemplateName
        ): java.lang.String
      )
      .repositoryName(RepositoryName.unwrap(repositoryName): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.codecommit.model.DisassociateApprovalRuleTemplateFromRepositoryRequest.ReadOnly =
    zio.aws.codecommit.model.DisassociateApprovalRuleTemplateFromRepositoryRequest
      .wrap(buildAwsValue())
}
object DisassociateApprovalRuleTemplateFromRepositoryRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codecommit.model.DisassociateApprovalRuleTemplateFromRepositoryRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.codecommit.model.DisassociateApprovalRuleTemplateFromRepositoryRequest =
      zio.aws.codecommit.model
        .DisassociateApprovalRuleTemplateFromRepositoryRequest(
          approvalRuleTemplateName,
          repositoryName
        )
    def approvalRuleTemplateName: ApprovalRuleTemplateName
    def repositoryName: RepositoryName
    def getApprovalRuleTemplateName
        : ZIO[Any, Nothing, ApprovalRuleTemplateName] =
      ZIO.succeed(approvalRuleTemplateName)
    def getRepositoryName: ZIO[Any, Nothing, RepositoryName] =
      ZIO.succeed(repositoryName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codecommit.model.DisassociateApprovalRuleTemplateFromRepositoryRequest
  ) extends zio.aws.codecommit.model.DisassociateApprovalRuleTemplateFromRepositoryRequest.ReadOnly {
    override val approvalRuleTemplateName: ApprovalRuleTemplateName =
      zio.aws.codecommit.model.primitives
        .ApprovalRuleTemplateName(impl.approvalRuleTemplateName())
    override val repositoryName: RepositoryName =
      zio.aws.codecommit.model.primitives.RepositoryName(impl.repositoryName())
  }
  def wrap(
      impl: software.amazon.awssdk.services.codecommit.model.DisassociateApprovalRuleTemplateFromRepositoryRequest
  ): zio.aws.codecommit.model.DisassociateApprovalRuleTemplateFromRepositoryRequest.ReadOnly =
    new Wrapper(impl)
}
